/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __CACHESTAT_BPF_SKEL_H__
#define __CACHESTAT_BPF_SKEL_H__

#include <stdlib.h>
#include <bpf/libbpf.h>

struct cachestat_bpf {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *add_to_page_cache_lru;
		struct bpf_program *mark_page_accessed;
		struct bpf_program *account_page_dirtied;
		struct bpf_program *mark_buffer_dirty;
	} progs;
	struct {
		struct bpf_link *add_to_page_cache_lru;
		struct bpf_link *mark_page_accessed;
		struct bpf_link *account_page_dirtied;
		struct bpf_link *mark_buffer_dirty;
	} links;
	struct cachestat_bpf__bss {
		__s64 total;
		__s64 misses;
		__u64 mbd;
	} *bss;
};

static void
cachestat_bpf__destroy(struct cachestat_bpf *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
cachestat_bpf__create_skeleton(struct cachestat_bpf *obj);

static inline struct cachestat_bpf *
cachestat_bpf__open_opts(const struct bpf_object_open_opts *opts)
{
	struct cachestat_bpf *obj;

	obj = (struct cachestat_bpf *)calloc(1, sizeof(*obj));
	if (!obj)
		return NULL;
	if (cachestat_bpf__create_skeleton(obj))
		goto err;
	if (bpf_object__open_skeleton(obj->skeleton, opts))
		goto err;

	return obj;
err:
	cachestat_bpf__destroy(obj);
	return NULL;
}

static inline struct cachestat_bpf *
cachestat_bpf__open(void)
{
	return cachestat_bpf__open_opts(NULL);
}

static inline int
cachestat_bpf__load(struct cachestat_bpf *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct cachestat_bpf *
cachestat_bpf__open_and_load(void)
{
	struct cachestat_bpf *obj;

	obj = cachestat_bpf__open();
	if (!obj)
		return NULL;
	if (cachestat_bpf__load(obj)) {
		cachestat_bpf__destroy(obj);
		return NULL;
	}
	return obj;
}

static inline int
cachestat_bpf__attach(struct cachestat_bpf *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
cachestat_bpf__detach(struct cachestat_bpf *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline int
cachestat_bpf__create_skeleton(struct cachestat_bpf *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		return -1;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "cachestat_bpf";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 1;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "cachesta.bss";
	s->maps[0].map = &obj->maps.bss;
	s->maps[0].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 4;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "add_to_page_cache_lru";
	s->progs[0].prog = &obj->progs.add_to_page_cache_lru;
	s->progs[0].link = &obj->links.add_to_page_cache_lru;

	s->progs[1].name = "mark_page_accessed";
	s->progs[1].prog = &obj->progs.mark_page_accessed;
	s->progs[1].link = &obj->links.mark_page_accessed;

	s->progs[2].name = "account_page_dirtied";
	s->progs[2].prog = &obj->progs.account_page_dirtied;
	s->progs[2].link = &obj->links.account_page_dirtied;

	s->progs[3].name = "mark_buffer_dirty";
	s->progs[3].prog = &obj->progs.mark_buffer_dirty;
	s->progs[3].link = &obj->links.mark_buffer_dirty;

	s->data_sz = 3920;
	s->data = (void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x90\x0a\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x13\0\
\x12\0\xb7\x01\0\0\x01\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdb\x12\0\0\0\
\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb7\x01\0\0\x01\0\0\0\x18\x02\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xdb\x12\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\
\xb7\x01\0\0\xff\xff\xff\xff\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdb\x12\0\0\0\
\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb7\x01\0\0\xff\xff\xff\xff\x18\x02\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdb\x12\0\0\0\0\0\0\xb7\x01\0\0\x01\0\0\0\x18\x02\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdb\x12\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\
\0\0\0\x47\x50\x4c\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\0\x94\x01\0\0\x94\x01\0\0\
\xa4\x02\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\x01\0\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\
\0\0\0\0\0\x01\0\0\x0d\x04\0\0\0\x18\0\0\0\x01\0\0\0\x1c\0\0\0\0\0\0\x01\x04\0\
\0\0\x20\0\0\x01\x20\0\0\0\x01\0\0\x0c\x03\0\0\0\0\0\0\0\x01\0\0\x0d\x04\0\0\0\
\x18\0\0\0\x01\0\0\0\xd5\0\0\0\x01\0\0\x0c\x06\0\0\0\0\0\0\0\x01\0\0\x0d\x04\0\
\0\0\x18\0\0\0\x01\0\0\0\x45\x01\0\0\x01\0\0\x0c\x08\0\0\0\0\0\0\0\x01\0\0\x0d\
\x04\0\0\0\x18\0\0\0\x01\0\0\0\xbd\x01\0\0\x01\0\0\x0c\x0a\0\0\0\x4b\x02\0\0\0\
\0\0\x08\x0d\0\0\0\x51\x02\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\x01\x5f\x02\0\0\0\0\
\0\x0e\x0c\0\0\0\x01\0\0\0\x65\x02\0\0\0\0\0\x0e\x0c\0\0\0\x01\0\0\0\x6c\x02\0\
\0\0\0\0\x08\x02\0\0\0\x72\x02\0\0\0\0\0\x0e\x10\0\0\0\x01\0\0\0\x76\x02\0\0\0\
\0\0\x01\x01\0\0\0\x08\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x12\0\0\0\x14\0\0\0\
\x04\0\0\0\x7b\x02\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\x8f\x02\0\0\0\0\0\x0e\x13\
\0\0\0\x01\0\0\0\x97\x02\0\0\x03\0\0\x0f\0\0\0\0\x0e\0\0\0\0\0\0\0\x08\0\0\0\
\x0f\0\0\0\0\0\0\0\x08\0\0\0\x11\0\0\0\0\0\0\0\x08\0\0\0\x9c\x02\0\0\x01\0\0\
\x0f\0\0\0\0\x15\0\0\0\0\0\0\0\x04\0\0\0\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\
\x20\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x63\x74\x78\0\x69\x6e\
\x74\0\x61\x64\x64\x5f\x74\x6f\x5f\x70\x61\x67\x65\x5f\x63\x61\x63\x68\x65\x5f\
\x6c\x72\x75\0\x66\x65\x6e\x74\x72\x79\x2f\x61\x64\x64\x5f\x74\x6f\x5f\x70\x61\
\x67\x65\x5f\x63\x61\x63\x68\x65\x5f\x6c\x72\x75\0\x2f\x75\x73\x72\x2f\x73\x72\
\x63\x2f\x52\x50\x4d\x2f\x42\x55\x49\x4c\x44\x2f\x62\x63\x63\x2d\x30\x2e\x31\
\x39\x2e\x30\x2f\x6c\x69\x62\x62\x70\x66\x2d\x74\x6f\x6f\x6c\x73\x2f\x63\x61\
\x63\x68\x65\x73\x74\x61\x74\x2e\x62\x70\x66\x2e\x63\0\x69\x6e\x74\x20\x42\x50\
\x46\x5f\x50\x52\x4f\x47\x28\x61\x64\x64\x5f\x74\x6f\x5f\x70\x61\x67\x65\x5f\
\x63\x61\x63\x68\x65\x5f\x6c\x72\x75\x29\0\x09\x5f\x5f\x73\x79\x6e\x63\x5f\x66\
\x65\x74\x63\x68\x5f\x61\x6e\x64\x5f\x61\x64\x64\x28\x26\x6d\x69\x73\x73\x65\
\x73\x2c\x20\x31\x29\x3b\0\x6d\x61\x72\x6b\x5f\x70\x61\x67\x65\x5f\x61\x63\x63\
\x65\x73\x73\x65\x64\0\x66\x65\x6e\x74\x72\x79\x2f\x6d\x61\x72\x6b\x5f\x70\x61\
\x67\x65\x5f\x61\x63\x63\x65\x73\x73\x65\x64\0\x69\x6e\x74\x20\x42\x50\x46\x5f\
\x50\x52\x4f\x47\x28\x6d\x61\x72\x6b\x5f\x70\x61\x67\x65\x5f\x61\x63\x63\x65\
\x73\x73\x65\x64\x29\0\x09\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\
\x61\x6e\x64\x5f\x61\x64\x64\x28\x26\x74\x6f\x74\x61\x6c\x2c\x20\x31\x29\x3b\0\
\x61\x63\x63\x6f\x75\x6e\x74\x5f\x70\x61\x67\x65\x5f\x64\x69\x72\x74\x69\x65\
\x64\0\x66\x65\x6e\x74\x72\x79\x2f\x61\x63\x63\x6f\x75\x6e\x74\x5f\x70\x61\x67\
\x65\x5f\x64\x69\x72\x74\x69\x65\x64\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\
\x4f\x47\x28\x61\x63\x63\x6f\x75\x6e\x74\x5f\x70\x61\x67\x65\x5f\x64\x69\x72\
\x74\x69\x65\x64\x29\0\x09\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\
\x61\x6e\x64\x5f\x61\x64\x64\x28\x26\x6d\x69\x73\x73\x65\x73\x2c\x20\x2d\x31\
\x29\x3b\0\x6d\x61\x72\x6b\x5f\x62\x75\x66\x66\x65\x72\x5f\x64\x69\x72\x74\x79\
\0\x66\x65\x6e\x74\x72\x79\x2f\x6d\x61\x72\x6b\x5f\x62\x75\x66\x66\x65\x72\x5f\
\x64\x69\x72\x74\x79\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x6d\
\x61\x72\x6b\x5f\x62\x75\x66\x66\x65\x72\x5f\x64\x69\x72\x74\x79\x29\0\x09\x5f\
\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\x61\x6e\x64\x5f\x61\x64\x64\
\x28\x26\x74\x6f\x74\x61\x6c\x2c\x20\x2d\x31\x29\x3b\0\x09\x5f\x5f\x73\x79\x6e\
\x63\x5f\x66\x65\x74\x63\x68\x5f\x61\x6e\x64\x5f\x61\x64\x64\x28\x26\x6d\x62\
\x64\x2c\x20\x31\x29\x3b\0\x5f\x5f\x73\x36\x34\0\x6c\x6f\x6e\x67\x20\x6c\x6f\
\x6e\x67\x20\x69\x6e\x74\0\x74\x6f\x74\x61\x6c\0\x6d\x69\x73\x73\x65\x73\0\x5f\
\x5f\x75\x36\x34\0\x6d\x62\x64\0\x63\x68\x61\x72\0\x5f\x5f\x41\x52\x52\x41\x59\
\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x4c\x49\x43\x45\x4e\x53\x45\
\0\x2e\x62\x73\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x9f\xeb\x01\0\x20\0\0\0\0\0\
\0\0\x44\0\0\0\x44\0\0\0\xf4\0\0\0\x38\x01\0\0\0\0\0\0\x08\0\0\0\x36\0\0\0\x01\
\0\0\0\0\0\0\0\x05\0\0\0\xe8\0\0\0\x01\0\0\0\0\0\0\0\x07\0\0\0\x5a\x01\0\0\x01\
\0\0\0\0\0\0\0\x09\0\0\0\xcf\x01\0\0\x01\0\0\0\0\0\0\0\x0b\0\0\0\x10\0\0\0\x36\
\0\0\0\x03\0\0\0\0\0\0\0\x53\0\0\0\x8e\0\0\0\0\x30\0\0\x08\0\0\0\x53\0\0\0\xb2\
\0\0\0\x02\x38\0\0\x20\0\0\0\x53\0\0\0\x8e\0\0\0\x05\x30\0\0\xe8\0\0\0\x03\0\0\
\0\0\0\0\0\x53\0\0\0\x02\x01\0\0\0\x4c\0\0\x08\0\0\0\x53\0\0\0\x23\x01\0\0\x02\
\x54\0\0\x20\0\0\0\x53\0\0\0\x02\x01\0\0\x05\x4c\0\0\x5a\x01\0\0\x03\0\0\0\0\0\
\0\0\x53\0\0\0\x76\x01\0\0\0\x68\0\0\x08\0\0\0\x53\0\0\0\x99\x01\0\0\x02\x70\0\
\0\x20\0\0\0\x53\0\0\0\x76\x01\0\0\x05\x68\0\0\xcf\x01\0\0\x04\0\0\0\0\0\0\0\
\x53\0\0\0\xe8\x01\0\0\0\x84\0\0\x08\0\0\0\x53\0\0\0\x08\x02\0\0\x02\x8c\0\0\
\x28\0\0\0\x53\0\0\0\x2b\x02\0\0\x02\x90\0\0\x40\0\0\0\x53\0\0\0\xe8\x01\0\0\
\x05\x84\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd5\0\0\0\x11\0\x07\0\0\0\0\0\0\0\
\0\0\x04\0\0\0\0\0\0\0\xa3\0\0\0\x12\0\x04\0\0\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\
\x29\0\0\0\x12\0\x02\0\0\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\x0c\0\0\0\x12\0\x05\0\
\0\0\0\0\0\0\0\0\x50\0\0\0\0\0\0\0\x85\0\0\0\x12\0\x03\0\0\0\0\0\0\0\0\0\x30\0\
\0\0\0\0\0\0\xb8\0\0\0\x11\0\x06\0\x10\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x57\0\0\
\0\x11\0\x06\0\x08\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x5e\0\0\0\x11\0\x06\0\0\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x01\0\0\0\x0b\0\0\0\x08\0\0\0\0\
\0\0\0\x01\0\0\0\x0c\0\0\0\x08\0\0\0\0\0\0\0\x01\0\0\0\x0b\0\0\0\x08\0\0\0\0\0\
\0\0\x01\0\0\0\x0c\0\0\0\x28\0\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x74\x01\0\0\0\0\
\0\0\0\0\0\0\x0c\0\0\0\x80\x01\0\0\0\0\0\0\0\0\0\0\x0b\0\0\0\x8c\x01\0\0\0\0\0\
\0\0\0\0\0\x0a\0\0\0\xa4\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x2c\0\0\0\0\0\0\0\0\
\0\0\0\x01\0\0\0\x3c\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x4c\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\x5c\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\x70\0\0\0\0\0\0\0\0\0\0\0\x01\0\
\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x90\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\
\xa8\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\xb8\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\xc8\0\
\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\xe0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\xf0\0\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x18\x01\0\0\0\0\0\
\0\0\0\0\0\x04\0\0\0\x28\x01\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\x38\x01\0\0\0\0\0\0\
\0\0\0\0\x04\0\0\0\x48\x01\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\x23\x25\x22\x24\x28\
\x27\x26\x21\0\x2e\x72\x65\x6c\x66\x65\x6e\x74\x72\x79\x2f\x6d\x61\x72\x6b\x5f\
\x62\x75\x66\x66\x65\x72\x5f\x64\x69\x72\x74\x79\0\x2e\x72\x65\x6c\x66\x65\x6e\
\x74\x72\x79\x2f\x61\x64\x64\x5f\x74\x6f\x5f\x70\x61\x67\x65\x5f\x63\x61\x63\
\x68\x65\x5f\x6c\x72\x75\0\x2e\x74\x65\x78\x74\0\x2e\x72\x65\x6c\x2e\x42\x54\
\x46\x2e\x65\x78\x74\0\x2e\x62\x73\x73\0\x6d\x69\x73\x73\x65\x73\0\x74\x6f\x74\
\x61\x6c\0\x2e\x6c\x6c\x76\x6d\x5f\x61\x64\x64\x72\x73\x69\x67\0\x6c\x69\x63\
\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x66\x65\x6e\x74\x72\x79\x2f\x6d\x61\x72\x6b\
\x5f\x70\x61\x67\x65\x5f\x61\x63\x63\x65\x73\x73\x65\x64\0\x2e\x72\x65\x6c\x66\
\x65\x6e\x74\x72\x79\x2f\x61\x63\x63\x6f\x75\x6e\x74\x5f\x70\x61\x67\x65\x5f\
\x64\x69\x72\x74\x69\x65\x64\0\x6d\x62\x64\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\
\x73\x79\x6d\x74\x61\x62\0\x2e\x72\x65\x6c\x2e\x42\x54\x46\0\x4c\x49\x43\x45\
\x4e\x53\x45\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3f\0\0\
\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x01\0\0\0\x06\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7e\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x70\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x9c\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa0\
\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x05\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd0\0\0\0\0\0\0\0\
\x50\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x52\0\0\0\
\x08\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\x01\0\0\0\0\0\0\x18\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x72\0\0\0\x01\0\0\0\x03\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\x01\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x24\x01\0\0\0\0\0\0\x50\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x49\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x74\x05\0\0\0\0\0\0\x58\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xc4\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd0\x06\0\0\0\
\0\0\0\x38\x01\0\0\0\0\0\0\x12\0\0\0\x05\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\
\0\0\x1e\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x08\0\0\0\0\0\0\
\x10\0\0\0\0\0\0\0\x0a\0\0\0\x02\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x7a\
\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x08\0\0\0\0\0\0\x10\0\0\0\
\0\0\0\0\x0a\0\0\0\x03\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x98\0\0\0\x09\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x28\x08\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\
\x0a\0\0\0\x04\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x01\0\0\0\x09\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x38\x08\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x0a\0\0\0\
\x05\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xcc\0\0\0\x09\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x58\x08\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x45\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x98\x08\0\0\0\0\0\0\x10\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x08\0\0\
\0\0\0\0\0\x10\0\0\0\0\0\0\0\x64\0\0\0\x03\x4c\xff\x6f\0\0\0\x80\0\0\0\0\0\0\0\
\0\0\0\0\0\xa8\x09\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\xbc\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb0\
\x09\0\0\0\0\0\0\xdd\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0";

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -1;
}

#endif /* __CACHESTAT_BPF_SKEL_H__ */
